﻿param
(
	[switch] $install,
	[switch] $uninstall
)

Function ExtractEmbeddedResourcesFromAssembly([System.Reflection.Assembly] $Assembly, [string] $SourcePath, [string] $TargetDirectoryPath)
{
	$ResourceStream = $Assembly.GetManifestResourceStream($SourcePath)
		
	if (-Not (Test-Path $TargetDirectoryPath)) 
	{
		New-Item $TargetDirectoryPath -type directory -force
	}
	
	$Splits = $SourcePath.Split(".")
	$FileName = $Splits[-2] + "." + $Splits[-1]
	$TargetResourcePath = Join-Path $TargetDirectoryPath $FileName

	if (($ResourceStream -ne $null) -and ($ResourceStream.Length -gt 0)) 
	{
		$buf = New-Object Byte[] $ResourceStream.Length
		$ResourceStream.Read($buf, 0, $buf.Length) | Out-Null
		[System.IO.File]::WriteAllBytes($TargetResourcePath, $buf)
		$ResourceStream.close()
	}
	return $TargetResourcePath
}

If ((-Not $install) -And (-Not $uninstall))
{
	Write-Host ""
	Write-Host "DESCRIPTION"
	Write-Host "    This script copies Esri’s JavaScript web content resources to SharePoint for use with Esri Maps for SharePoint"
	Write-Host ""
	Write-Host "SYNTAX"
	Write-Host "    WebContentInstaller.ps1 -install | -uninstall"
	Write-Host ""
	Exit
}

$HiveLocation = ""

If (Test-Path "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\15.0") 
{
	if ((Get-ItemProperty  "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\15.0" | %{$_.SharePoint})  -eq "Installed") 
	{
		$HiveLocation = Get-ItemProperty  "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\15.0" | %{$_.Location}
	}	
}

if ($HiveLocation -eq "")
{
	If (Test-Path "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\14.0")
    {
	    if ((Get-ItemProperty  "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\14.0" | %{$_.SharePoint})  -eq "Installed") 
	    {
			$HiveLocation = Get-ItemProperty "HKLM:\SOFTWARE\Microsoft\Shared Tools\Web Server Extensions\14.0" | %{$_.Location}
    	}
    }
}   

if ($HiveLocation -ne "")
{
	$InstallLocation = Join-Path $HiveLocation "TEMPLATE\LAYOUTS\ESRI.ArcGIS.Mapping.SharePoint\scripts"
	
	Try	
	{
		if ($PSScriptRoot -eq $null) 
        {
            $PSScriptRoot = Split-Path $MyInvocation.MyCommand.Path -Parent
        }
        $AssemblyPath = Join-Path $PSScriptRoot "Setup.exe"
		$Assembly = [System.Reflection.Assembly]::LoadFrom($AssemblyPath)
	}
	Catch 
	{
		Write-Host "Failed to load assembly."
		Exit
	}
	
	Try
	{	
		$LocalTempPath = Join-Path (Get-Childitem env:LOCALAPPDATA | %{$_.Value}) "Temp"
		$WebContentZipPath = ExtractEmbeddedResourcesFromAssembly $Assembly "ESRI.ArcGIS.Mapping.SharePoint.Installer.Resources.EsriMapsWebContents.zip" $LocalTempPath
		$ZipForgeLibPath = ExtractEmbeddedResourcesFromAssembly $Assembly "ESRI.ArcGIS.Mapping.SharePoint.Installer.Resources.ZipForge.dll" $LocalTempPath
	}
	Catch 
	{
		Write-Host "Failed to extract resource."
		Exit
	}

	if (Test-Path $InstallLocation)
	{
		Write-Host "Removing the existing JavaScript web content files."		
		CMD /C rmdir "$InstallLocation" /S /Q
        if ($uninstall) 
        {
            Write-Host "JavaScript web content has been removed successfully."
        }
	} 

	if ($install) 
	{
		Write-Host "Waiting for the JavaScript web content to install. This may take several minutes."
		$TempInstallPath = Join-Path $LocalTempPath "esri_temp"
		if (Test-Path $TempInstallPath)
		{
			Remove-Item $TempInstallPath -force
		}
		New-Item $TempInstallPath -type directory -force
		[Reflection.Assembly]::LoadFile($ZipForgeLibPath) | out-null
		$Archiver = New-Object ComponentAce.Compression.ZipForge.ZipForge
		$Archiver.FileName = $WebContentZipPath 
		$Archiver.OpenArchive()
		$Archiver.BaseDir = $TempInstallPath
		$Archiver.ExtractFiles("*.*")
		$Archiver.CloseArchive()
		
		Remove-Item $WebContentZipPath
		Remove-Item $ZipForgeLibPath
		Robocopy $TempInstallPath $InstallLocation /S /E /MIR /MOVE
        Write-Host "JavaScript web content deployment has completed successfully."
	}		
}
else 
{
	Write-Host "SharePoint is not installed."
}